@@ -1,5 +1,5 @@
-#This file is part of Tryton.  The COPYRIGHT file at the top level of
-#this repository contains the full copyright notices and license terms.
+# This file is part of Tryton.  The COPYRIGHT file at the top level of
+# this repository contains the full copyright notices and license terms.
 from decimal import Decimal
 import datetime
 
@@ -82,6 +82,8 @@ class Work:
                         costs[work_id] += (
                             Decimal(str(timesheet_work.hours)) * cost)
                 to_date = from_date - datetime.timedelta(1)
+        for work in works:
+            costs[work.id] = work.company.currency.round(costs[work.id])
         return costs
 
     @classmethod
@@ -92,7 +94,7 @@ class Work:
 
         def getter(work):
             if work.list_price:
-                return work.list_price * Decimal(str(work.effort))
+                return work.list_price * Decimal(str(work.effort_hours))
             else:
                 return Decimal(0)
 
@@ -113,7 +115,7 @@ class Work:
             return company.currency.digits
         return 2
 
-    @fields.depends('product', 'party', 'hours', 'company')
+    @fields.depends('product', 'party', 'company')
     def on_change_product(self):
         pool = Pool()
         User = pool.get('res.user')
@@ -122,7 +124,7 @@ class Work:
         Currency = pool.get('currency.currency')
 
         if not self.product:
-            return {}
+            return
 
         context = {}
 
@@ -132,14 +134,12 @@ class Work:
         hour_uom = Uom(ModelData.get_id('product', 'uom_hour'))
 
         with Transaction().set_context(context):
-            list_price = Uom.compute_price(self.product.default_uom,
+            self.list_price = Uom.compute_price(self.product.default_uom,
                 self.product.list_price, hour_uom)
 
         if self.company:
             user = User(Transaction().user)
             if user.company != self.company:
                 if user.company.currency != self.company.currency:
-                    list_price = Currency.compute(user.company.currency,
-                        list_price, self.company.currency)
-
-        return {'list_price': list_price}
+                    self.list_price = Currency.compute(user.company.currency,
+                        self.list_price, self.company.currency)
